@@ -15,9 +15,6 @@ remove_command("dh_auto_install");
 insert_after("dh_auto_test", "dh_raku_test");
 remove_command("dh_auto_test");
 
-# cleanup precompiled files
-insert_after("dh_clean", "dh_raku_clean");
-
 remove_command("dh_prep");
 
 1;
